browser.contextMenus.create({
    id: "encode-with-mcp",
    title: "Encode with MagiCoder Pro",
    contexts: ["selection", "editable"]
});

browser.contextMenus.onClicked.addListener(async function(info, tab) {
    if (info.menuItemId === "encode-with-mcp") {
        let sourceText = info.selectionText || (await browser.tabs.sendMessage(tab.id, {command: 'getSourceText', frameId: info.frameId, targetElementId: info.targetElementId })).sourceText;;
        browser.runtime.sendMessage({command: 'showSourceText', sourceText: `«${sourceText}»`});
	let MCPRecognizedTerms = await encodeWithMCP(sourceText);
        browser.runtime.sendMessage({command: 'showRecognizedTerms', MCPRecognizedTerms: MCPRecognizedTerms});
    }
});

async function encodeWithMCP(sourceText) {
    let mcpWorker = (await browser.storage.sync.get('mcpWorker')).mcpWorker;
    let mcpAPIAccessToken = (await browser.storage.sync.get('mcpAPIAccessToken')).mcpAPIAccessToken;
    let mcpAPISecretToken = (await browser.storage.sync.get('mcpAPISecretToken')).mcpAPISecretToken;

    let MCPResponse = await (await fetch('https://' + mcpWorker + '/api/v2/encode?' + new URLSearchParams({to_encode: sourceText}), {
        method: 'GET',
        mode: 'cors',
        headers: {'Access-Token': mcpAPIAccessToken, 'Secret-Token': mcpAPISecretToken}
    })).json();

    if (MCPResponse.message == 'Limit exceeded') return '<p class="mcp-error">You have reached the maximum number of API calls allowed for your account.</p>';

    let MCPRecognizedTerms = (MCPResponse.length < 1) ? '<p class="mcp-error">No recognized terms.</p>' :
             '<ul>' + MCPResponse.reduce((a,term) => `${a}<li><code data-bs-toggle="tooltip" title="Click to copy" data-clipboard-text="${term.id}">${term.id}</code> <span data-bs-toggle="tooltip" title="Click to copy" data-clipboard-text="${term.name}">${term.name}</span></li>`, '') + '</ul>'

    return MCPRecognizedTerms;
 }
